==> 0.0.2.tar.gz: lib/cs_ironsource_ad.dart <==
import 'dart:async';
import 'dart:developer';

import 'package:flutter/services.dart';

typedef OfferwallAvailable = void Function(bool isAvailable);
typedef OfferwallOpened = void Function();
typedef OfferwallShowFailed = void Function(int code);
typedef OfferwallAdCredited = void Function(int credits, int totalCredits, bool totalCreditsFlag);
typedef GetOfferwallCreditsFailed = void Function(int code);
typedef OfferwallClosed = void Function();

typedef RewardedVideoAdOpened = void Function();
typedef RewardedVideoAdClosed = void Function();
typedef RewardedVideoAvailabilityChanged = void Function(bool isAvailable);
typedef RewardedVideoAdStarted = void Function();
typedef RewardedVideoAdEnded = void Function();
typedef RewardedVideoAdRewarded = void Function(String rewardName, int rewardAmount);
typedef RewardedVideoAdShowFailed = void Function(int code);
typedef RewardedVideoAdClicked = void Function(String rewardName, int rewardAmount);

typedef InterstitialAdReady = void Function();
typedef InterstitialAdLoadFailed = void Function(int code);
typedef InterstitialAdOpened = void Function();
typedef InterstitialAdClosed = void Function();
typedef InterstitialAdShowSucceeded = void Function();
typedef InterstitialAdShowFailed = void Function(int code);
typedef InterstitialAdClicked = void Function();

class CsIronsourceAd {
  final MethodChannel _channel = const MethodChannel('cs_ironsource_android');
  static final CsIronsourceAd _instance = CsIronsourceAd._internal();
  factory CsIronsourceAd() => _instance;
  CsIronsourceAd._internal() {
    _channel.setMethodCallHandler(_platformCallHandler);
  }

  late OfferwallAvailable _offerwallAvailable;
  late OfferwallOpened _offerwallOpened;
  late OfferwallShowFailed _offerwallShowFailed;
  late OfferwallAdCredited _offerwallAdCredited;
  late GetOfferwallCreditsFailed _getOfferwallCreditsFailed;
  late OfferwallClosed _offerwallClosed;

  late RewardedVideoAdOpened _rewardedVideoAdOpened;
  late RewardedVideoAdClosed _rewardedVideoAdClosed;
  late RewardedVideoAvailabilityChanged _rewardedVideoAvailabilityChanged;
  late RewardedVideoAdStarted _rewardedVideoAdStarted;
  late RewardedVideoAdEnded _rewardedVideoAdEnded;
  late RewardedVideoAdRewarded _rewardedVideoAdRewarded;
  late RewardedVideoAdShowFailed _rewardedVideoAdShowFailed;
  late RewardedVideoAdClicked _rewardedVideoAdClicked;

  late InterstitialAdReady _interstitialAdReady;
  late InterstitialAdLoadFailed _interstitialAdLoadFailed;
  late InterstitialAdOpened _interstitialAdOpened;
  late InterstitialAdClosed _interstitialAdClosed;
  late InterstitialAdShowSucceeded _interstitialAdShowSucceeded;
  late InterstitialAdShowFailed _interstitialAdShowFailed;
  late InterstitialAdClicked _interstitialAdClicked;

  Future _platformCallHandler(MethodCall call) async {
    switch (call.method) {
      case "offerwallAvailable":
        _offerwallAvailable(call.arguments?[0]);
        break;
      case "offerwallOpened":
        _offerwallOpened();
        break;
      case "offerwallShowFailed":
        _offerwallShowFailed(call.arguments?[0]);
        break;
      case "offerwallAdCredited":
        _offerwallAdCredited(call.arguments?[0], call.arguments?[1], call.arguments?[2]);
        break;
      case "getOfferwallCreditsFailed":
        _getOfferwallCreditsFailed(call.arguments);
        break;
      case "offerwallClosed":
        _offerwallClosed();
        break;

      case "rewardedVideoAdClicked":
        _rewardedVideoAdClicked(call.arguments?[0], call.arguments?[1]);
        break;
      case "rewardedVideoAdShowFailed":
        _rewardedVideoAdShowFailed(call.arguments?[0]);
        break;
      case "rewardedVideoAdRewarded":
        _rewardedVideoAdRewarded(call.arguments?[0], call.arguments?[1]);
        break;
      case "rewardedVideoAdEnded":
        _rewardedVideoAdEnded();
        break;
      case "rewardedVideoAdStarted":
        _rewardedVideoAdStarted();
        break;
      case "rewardedVideoAvailabilityChanged":
        _rewardedVideoAvailabilityChanged(call.arguments?[0]);
        break;
      case "rewardedVideoAdClosed":
        _rewardedVideoAdClosed();
        break;
      case "rewardedVideoAdOpened":
        _rewardedVideoAdOpened();
        break;
      case "interstitialAdClicked":
        _interstitialAdClicked();
        break;
      case "interstitialAdShowFailed":
        _interstitialAdShowFailed(call.arguments?[0]);
        break;
      case "interstitialAdShowSucceeded":
        _interstitialAdShowSucceeded();
        break;
      case "interstitialAdClosed":
        _interstitialAdClosed();
        break;
      case "interstitialAdOpened":
        _interstitialAdOpened();
        break;
      case "interstitialAdLoadFailed":
        _interstitialAdLoadFailed(call.arguments?[0]);
        break;
      case "interstitialAdReady":
        _interstitialAdReady();
        break;
      default:
        log('Unknown method ${call.method} ');
    }
  }

  /// 初始化
  Future<void> initSDK({required String appKey}) async {
    return _channel.invokeMethod("init", <String, dynamic>{
      'appKey': appKey,
    });
  }

  Future<void> setUserId({required String userId}) async {
    return _channel.invokeMethod("setUserId", <String, dynamic>{
      'userId': userId,
    });
  }

  /// 获取积分墙积分
  Future<void> getOfferwallCredits() {
    return _channel.invokeMethod("getOfferwallCredits", <String, dynamic>{});
  }

  /// 展示积分墙
  Future<void> showOfferwallAd(String name) {
    return _channel.invokeMethod("showOfferWall", <String, dynamic>{
      'name': name,
    });
  }

  /// 展示视频广告
  Future<void> showVideoAd(String name) {
    return _channel.invokeMethod("showVideo", <String, dynamic>{
      'name': name,
    });
  }

  /// 展示插页广告
  Future<void> showInterstitialAd(String name) {
    return _channel.invokeMethod("showInterstitial", <String, dynamic>{
      'name': name,
    });
  }

  /// 加载视频广告
  Future<void> loadVideo() {
    return _channel.invokeMethod("loadRewardedVideo", <String, dynamic>{});
  }

  /// 加载插页广告
  Future<void> loadInterstitial(String name) {
    return _channel.invokeMethod("loadInterstitial", <String, dynamic>{});
  }

  /// 验证某个插页展示位置是否有上限
  Future<bool?> isInterstitialPlacementCapped() {
    return _channel.invokeMethod<bool>("isInterstitialPlacementCapped", <String, dynamic>{});
  }

  /// 验证某个展示位置是否有激励视频
  Future<bool?> isRewardedVideoPlacementCapped() {
    return _channel.invokeMethod<bool>("isRewardedVideoPlacementCapped", <String, dynamic>{});
  }

  /// 积分墙是否可用回调
  void setOfferwallAvailable(OfferwallAvailable offerwallAvailable) => _offerwallAvailable = offerwallAvailable;

  /// 积分墙打开
  void setOfferwallOpened(OfferwallOpened offerwallOpened) => _offerwallOpened = offerwallOpened;

  /// 积分墙展示错误
  void setOfferwallShowFailed(OfferwallShowFailed offerwallShowFailed) => _offerwallShowFailed = offerwallShowFailed;

  /// 返回积分墙积分
  void setOfferwallAdCredited(OfferwallAdCredited offerwallAdCredited) => _offerwallAdCredited = offerwallAdCredited;

  /// 获取积分墙积分失败
  void setGetOfferwallCreditsFailed(GetOfferwallCreditsFailed getOfferwallCreditsFailed) => _getOfferwallCreditsFailed = getOfferwallCreditsFailed;

  /// 积分墙关闭
  void setOfferwallClosed(OfferwallClosed offerwallClosed) => _offerwallClosed = offerwallClosed;

  /// 打开激励视频
  void setRewardedVideoAdOpened(RewardedVideoAdOpened rewardedVideoAdOpened) => _rewardedVideoAdOpened = rewardedVideoAdOpened;

  /// 关闭激励视频
  void setRewardedVideoAdClosed(RewardedVideoAdClosed rewardedVideoAdClosed) => _rewardedVideoAdClosed = rewardedVideoAdClosed;

  /// 激励视频可用性改变
  void setRewardedVideoAvailabilityChanged(RewardedVideoAvailabilityChanged rewardedVideoAvailabilityChanged) => _rewardedVideoAvailabilityChanged = rewardedVideoAvailabilityChanged;

  /// 激励视频开始播放
  void setRewardedVideoAdStarted(RewardedVideoAdStarted rewardedVideoAdStarted) => _rewardedVideoAdStarted = rewardedVideoAdStarted;

  /// 激励视频结束播放
  void setRewardedVideoAdEnded(RewardedVideoAdEnded rewardedVideoAdEnded) => _rewardedVideoAdEnded = rewardedVideoAdEnded;

  /// 激励视频获取奖励
  void setRewardedVideoAdRewarded(RewardedVideoAdRewarded rewardedVideoAdRewarded) => _rewardedVideoAdRewarded = rewardedVideoAdRewarded;

  /// 激励视频展示失败
  void setRewardedVideoAdShowFailed(RewardedVideoAdShowFailed rewardedVideoAdShowFailed) => _rewardedVideoAdShowFailed = rewardedVideoAdShowFailed;

  /// 点击激励视频
  void setRewardedVideoAdClicked(RewardedVideoAdClicked rewardedVideoAdClicked) => _rewardedVideoAdClicked = rewardedVideoAdClicked;

  /// 准备好插页广告
  void setInterstitialAdReady(InterstitialAdReady interstitialAdReady) => _interstitialAdReady = interstitialAdReady;

  /// 插页广告获取失败
  void setInterstitialAdLoadFailed(InterstitialAdLoadFailed interstitialAdLoadFailed) => _interstitialAdLoadFailed = interstitialAdLoadFailed;

  /// 插页式广告打开
  void setInterstitialAdOpened(InterstitialAdOpened interstitialAdOpened) => _interstitialAdOpened = interstitialAdOpened;

  /// 插页式广告关闭
  void setInterstitialAdClosed(InterstitialAdClosed interstitialAdClosed) => _interstitialAdClosed = interstitialAdClosed;

  /// 插页式广告展示成功
  void setInterstitialAdShowSucceeded(InterstitialAdShowSucceeded interstitialAdShowSucceeded) => _interstitialAdShowSucceeded = interstitialAdShowSucceeded;

  /// 插页式广告展示失败
  void setInterstitialAdShowFailed(InterstitialAdShowFailed interstitialAdShowFailed) => _interstitialAdShowFailed = interstitialAdShowFailed;

  /// 点击插页广告
  void setInterstitialAdClicked(InterstitialAdClicked interstitialAdClicked) => _interstitialAdClicked = interstitialAdClicked;
}

==> 0.0.3.tar.gz: lib/cs_ironsource_ad.dart <==
import 'dart:async';
import 'dart:developer';

import 'package:flutter/services.dart';

typedef OfferwallAvailable = void Function(bool isAvailable);
typedef OfferwallOpened = void Function();
typedef OfferwallShowFailed = void Function(int code);
typedef OfferwallAdCredited = void Function(int credits, int totalCredits, bool totalCreditsFlag);
typedef GetOfferwallCreditsFailed = void Function(int code);
typedef OfferwallClosed = void Function();

typedef RewardedVideoAdOpened = void Function();
typedef RewardedVideoAdClosed = void Function();
typedef RewardedVideoAvailabilityChanged = void Function(bool isAvailable);
typedef RewardedVideoAdStarted = void Function();
typedef RewardedVideoAdEnded = void Function();
typedef RewardedVideoAdRewarded = void Function(String rewardName, int rewardAmount);
typedef RewardedVideoAdShowFailed = void Function(int code);
typedef RewardedVideoAdClicked = void Function(String rewardName, int rewardAmount);

typedef InterstitialAdReady = void Function();
typedef InterstitialAdLoadFailed = void Function(int code);
typedef InterstitialAdOpened = void Function();
typedef InterstitialAdClosed = void Function();
typedef InterstitialAdShowSucceeded = void Function();
typedef InterstitialAdShowFailed = void Function(int code);
typedef InterstitialAdClicked = void Function();

class CsIronsourceAd {
  final MethodChannel _channel = const MethodChannel('cs_ironsource_android');
  static final CsIronsourceAd _instance = CsIronsourceAd._internal();
  factory CsIronsourceAd() => _instance;
  CsIronsourceAd._internal() {
    _channel.setMethodCallHandler(_platformCallHandler);
  }

  late OfferwallAvailable _offerwallAvailable;
  late OfferwallOpened _offerwallOpened;
  late OfferwallShowFailed _offerwallShowFailed;
  late OfferwallAdCredited _offerwallAdCredited;
  late GetOfferwallCreditsFailed _getOfferwallCreditsFailed;
  late OfferwallClosed _offerwallClosed;

  late RewardedVideoAdOpened _rewardedVideoAdOpened;
  late RewardedVideoAdClosed _rewardedVideoAdClosed;
  late RewardedVideoAvailabilityChanged _rewardedVideoAvailabilityChanged;
  late RewardedVideoAdStarted _rewardedVideoAdStarted;
  late RewardedVideoAdEnded _rewardedVideoAdEnded;
  late RewardedVideoAdRewarded _rewardedVideoAdRewarded;
  late RewardedVideoAdShowFailed _rewardedVideoAdShowFailed;
  late RewardedVideoAdClicked _rewardedVideoAdClicked;

  late InterstitialAdReady _interstitialAdReady;
  late InterstitialAdLoadFailed _interstitialAdLoadFailed;
  late InterstitialAdOpened _interstitialAdOpened;
  late InterstitialAdClosed _interstitialAdClosed;
  late InterstitialAdShowSucceeded _interstitialAdShowSucceeded;
  late InterstitialAdShowFailed _interstitialAdShowFailed;
  late InterstitialAdClicked _interstitialAdClicked;

  Future _platformCallHandler(MethodCall call) async {
    switch (call.method) {
      case "offerwallAvailable":
        _offerwallAvailable(call.arguments?[0]);
        break;
      case "offerwallOpened":
        _offerwallOpened();
        break;
      case "offerwallShowFailed":
        _offerwallShowFailed(call.arguments?[0]);
        break;
      case "offerwallAdCredited":
        _offerwallAdCredited(call.arguments?[0], call.arguments?[1], call.arguments?[2]);
        break;
      case "getOfferwallCreditsFailed":
        _getOfferwallCreditsFailed(call.arguments);
        break;
      case "offerwallClosed":
        _offerwallClosed();
        break;

      case "rewardedVideoAdClicked":
        _rewardedVideoAdClicked(call.arguments?[0], call.arguments?[1]);
        break;
      case "rewardedVideoAdShowFailed":
        _rewardedVideoAdShowFailed(call.arguments?[0]);
        break;
      case "rewardedVideoAdRewarded":
        _rewardedVideoAdRewarded(call.arguments?[0], call.arguments?[1]);
        break;
      case "rewardedVideoAdEnded":
        _rewardedVideoAdEnded();
        break;
      case "rewardedVideoAdStarted":
        _rewardedVideoAdStarted();
        break;
      case "rewardedVideoAvailabilityChanged":
        _rewardedVideoAvailabilityChanged(call.arguments?[0]);
        break;
      case "rewardedVideoAdClosed":
        _rewardedVideoAdClosed();
        break;
      case "rewardedVideoAdOpened":
        _rewardedVideoAdOpened();
        break;
      case "interstitialAdClicked":
        _interstitialAdClicked();
        break;
      case "interstitialAdShowFailed":
        _interstitialAdShowFailed(call.arguments?[0]);
        break;
      case "interstitialAdShowSucceeded":
        _interstitialAdShowSucceeded();
        break;
      case "interstitialAdClosed":
        _interstitialAdClosed();
        break;
      case "interstitialAdOpened":
        _interstitialAdOpened();
        break;
      case "interstitialAdLoadFailed":
        _interstitialAdLoadFailed(call.arguments?[0]);
        break;
      case "interstitialAdReady":
        _interstitialAdReady();
        break;
      default:
        log('Unknown method ${call.method} ');
    }
  }

  Future<void> onResume() async {
    return _channel.invokeMethod("onResume", <String, dynamic>{});
  }

  Future<void> onPause() async {
    return _channel.invokeMethod("onPause", <String, dynamic>{});
  }

  /// 初始化
  Future<void> initSDK({required String appKey}) async {
    return _channel.invokeMethod("init", <String, dynamic>{
      'appKey': appKey,
    });
  }

  Future<void> setUserId({required String userId}) async {
    return _channel.invokeMethod("setUserId", <String, dynamic>{
      'userId': userId,
    });
  }

  /// 获取积分墙积分
  Future<void> getOfferwallCredits() {
    return _channel.invokeMethod("getOfferwallCredits", <String, dynamic>{});
  }

  /// 展示积分墙
  Future<void> showOfferwall(String name) {
    return _channel.invokeMethod("showOfferWall", <String, dynamic>{
      'name': name,
    });
  }

  /// 展示视频广告
  Future<void> showRewardedVideo(String name) {
    return _channel.invokeMethod("showRewardedVideo", <String, dynamic>{
      'name': name,
    });
  }

  /// 展示插页广告
  Future<void> showInterstitial(String name) {
    return _channel.invokeMethod("showInterstitial", <String, dynamic>{
      'name': name,
    });
  }

  /// 加载视频广告
  Future<void> loadVideo() {
    return _channel.invokeMethod("loadRewardedVideo", <String, dynamic>{});
  }

  /// 加载插页广告
  Future<void> loadInterstitial(String name) {
    return _channel.invokeMethod("loadInterstitial", <String, dynamic>{});
  }

  /// 验证某个插页展示位置是否有上限
  Future<bool?> isInterstitialPlacementCapped() {
    return _channel.invokeMethod<bool>("isInterstitialPlacementCapped", <String, dynamic>{});
  }

  /// 验证某个展示位置是否有激励视频
  Future<bool?> isRewardedVideoPlacementCapped() {
    return _channel.invokeMethod<bool>("isRewardedVideoPlacementCapped", <String, dynamic>{});
  }

  /// 积分墙是否可用
  Future<bool?> isOfferwallAvailable() {
    return _channel.invokeMethod<bool>("isOfferwallAvailable", <String, dynamic>{});
  }

  /// 激励视频是否可用
  Future<bool?> isRewardedVideoAvailable() {
    return _channel.invokeMethod<bool>("isRewardedVideoAvailable", <String, dynamic>{});
  }

  /// 插页广告是否可用
  Future<bool?> isInterstitialReady() {
    return _channel.invokeMethod<bool>("isInterstitialReady", <String, dynamic>{});
  }

  /// 积分墙是否可用回调
  void setOfferwallAvailable(OfferwallAvailable offerwallAvailable) => _offerwallAvailable = offerwallAvailable;

  /// 积分墙打开
  void setOfferwallOpened(OfferwallOpened offerwallOpened) => _offerwallOpened = offerwallOpened;

  /// 积分墙展示错误
  void setOfferwallShowFailed(OfferwallShowFailed offerwallShowFailed) => _offerwallShowFailed = offerwallShowFailed;

  /// 返回积分墙积分
  void setOfferwallAdCredited(OfferwallAdCredited offerwallAdCredited) => _offerwallAdCredited = offerwallAdCredited;

  /// 获取积分墙积分失败
  void setGetOfferwallCreditsFailed(GetOfferwallCreditsFailed getOfferwallCreditsFailed) => _getOfferwallCreditsFailed = getOfferwallCreditsFailed;

  /// 积分墙关闭
  void setOfferwallClosed(OfferwallClosed offerwallClosed) => _offerwallClosed = offerwallClosed;

  /// 打开激励视频
  void setRewardedVideoAdOpened(RewardedVideoAdOpened rewardedVideoAdOpened) => _rewardedVideoAdOpened = rewardedVideoAdOpened;

  /// 关闭激励视频
  void setRewardedVideoAdClosed(RewardedVideoAdClosed rewardedVideoAdClosed) => _rewardedVideoAdClosed = rewardedVideoAdClosed;

  /// 激励视频可用性改变
  void setRewardedVideoAvailabilityChanged(RewardedVideoAvailabilityChanged rewardedVideoAvailabilityChanged) => _rewardedVideoAvailabilityChanged = rewardedVideoAvailabilityChanged;

  /// 激励视频开始播放
  void setRewardedVideoAdStarted(RewardedVideoAdStarted rewardedVideoAdStarted) => _rewardedVideoAdStarted = rewardedVideoAdStarted;

  /// 激励视频结束播放
  void setRewardedVideoAdEnded(RewardedVideoAdEnded rewardedVideoAdEnded) => _rewardedVideoAdEnded = rewardedVideoAdEnded;

  /// 激励视频获取奖励
  void setRewardedVideoAdRewarded(RewardedVideoAdRewarded rewardedVideoAdRewarded) => _rewardedVideoAdRewarded = rewardedVideoAdRewarded;

  /// 激励视频展示失败
  void setRewardedVideoAdShowFailed(RewardedVideoAdShowFailed rewardedVideoAdShowFailed) => _rewardedVideoAdShowFailed = rewardedVideoAdShowFailed;

  /// 点击激励视频
  void setRewardedVideoAdClicked(RewardedVideoAdClicked rewardedVideoAdClicked) => _rewardedVideoAdClicked = rewardedVideoAdClicked;

  /// 准备好插页广告
  void setInterstitialAdReady(InterstitialAdReady interstitialAdReady) => _interstitialAdReady = interstitialAdReady;

  /// 插页广告获取失败
  void setInterstitialAdLoadFailed(InterstitialAdLoadFailed interstitialAdLoadFailed) => _interstitialAdLoadFailed = interstitialAdLoadFailed;

  /// 插页式广告打开
  void setInterstitialAdOpened(InterstitialAdOpened interstitialAdOpened) => _interstitialAdOpened = interstitialAdOpened;

  /// 插页式广告关闭
  void setInterstitialAdClosed(InterstitialAdClosed interstitialAdClosed) => _interstitialAdClosed = interstitialAdClosed;

  /// 插页式广告展示成功
  void setInterstitialAdShowSucceeded(InterstitialAdShowSucceeded interstitialAdShowSucceeded) => _interstitialAdShowSucceeded = interstitialAdShowSucceeded;

  /// 插页式广告展示失败
  void setInterstitialAdShowFailed(InterstitialAdShowFailed interstitialAdShowFailed) => _interstitialAdShowFailed = interstitialAdShowFailed;

  /// 点击插页广告
  void setInterstitialAdClicked(InterstitialAdClicked interstitialAdClicked) => _interstitialAdClicked = interstitialAdClicked;
}
